==> mingw-w64-clang-aarch64-flecs-docs-4.0.1-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/group__c__addons__units.js <==
var group__c__addons__units =
[
    [ "Prefixes", "group__c__addons__units__prefixes.html", "group__c__addons__units__prefixes" ],
    [ "Duration", "group__c__addons__units__duration.html", "group__c__addons__units__duration" ],
    [ "Time", "group__c__addons__units__time.html", "group__c__addons__units__time" ],
    [ "Mass", "group__c__addons__units__mass.html", "group__c__addons__units__mass" ],
    [ "Electric Current", "group__c__addons__units__electric__Current.html", "group__c__addons__units__electric__Current" ],
    [ "Amount", "group__c__addons__units__amount.html", "group__c__addons__units__amount" ],
    [ "Luminous Intensity", "group__c__addons__units__luminous__intensity.html", "group__c__addons__units__luminous__intensity" ],
    [ "Force", "group__c__addons__units__force.html", "group__c__addons__units__force" ],
    [ "Length", "group__c__addons__units__length.html", "group__c__addons__units__length" ],
    [ "Pressure", "group__c__addons__units__pressure.html", "group__c__addons__units__pressure" ],
    [ "Speed", "group__c__addons__units__speed.html", "group__c__addons__units__speed" ],
    [ "Temperature", "group__c__addons__units__temperature.html", "group__c__addons__units__temperature" ],
    [ "Data", "group__c__addons__units__data.html", "group__c__addons__units__data" ],
    [ "Data Rate", "group__c__addons__units__datarate.html", "group__c__addons__units__datarate" ],
    [ "Angle", "group__c__addons__units__angle.html", "group__c__addons__units__angle" ],
    [ "Uri", "group__c__addons__units__uri.html", "group__c__addons__units__uri" ],
    [ "Color", "group__c__addons__units__color.html", "group__c__addons__units__color" ],
    [ "ECS_DECLARE", "group__c__addons__units.html#ga3570414a2ba04baac77480d1076bed17", null ],
    [ "ECS_DECLARE", "group__c__addons__units.html#ga6b12ede2ed6975b18a0e9b6d9666457f", null ],
    [ "ECS_DECLARE", "group__c__addons__units.html#ga6bf9c12f48d4c8f19a2aedb7046c0955", null ],
    [ "ECS_DECLARE", "group__c__addons__units.html#gafbeea30ac2e4c125dfd086465c936816", null ],
    [ "FlecsUnitsImport", "group__c__addons__units.html#ga1a262c645dc495fbd6754a69f6c8bd60", null ]
];

==> mingw-w64-clang-aarch64-flecs-docs-4.0.4-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/group__c__addons__units.js <==
var group__c__addons__units =
[
    [ "Prefixes", "group__c__addons__units__prefixes.html", "group__c__addons__units__prefixes" ],
    [ "Duration", "group__c__addons__units__duration.html", "group__c__addons__units__duration" ],
    [ "Time", "group__c__addons__units__time.html", "group__c__addons__units__time" ],
    [ "Mass", "group__c__addons__units__mass.html", "group__c__addons__units__mass" ],
    [ "Electric Current", "group__c__addons__units__electric__Current.html", "group__c__addons__units__electric__Current" ],
    [ "Amount", "group__c__addons__units__amount.html", "group__c__addons__units__amount" ],
    [ "Luminous Intensity", "group__c__addons__units__luminous__intensity.html", "group__c__addons__units__luminous__intensity" ],
    [ "Force", "group__c__addons__units__force.html", "group__c__addons__units__force" ],
    [ "Length", "group__c__addons__units__length.html", "group__c__addons__units__length" ],
    [ "Pressure", "group__c__addons__units__pressure.html", "group__c__addons__units__pressure" ],
    [ "Speed", "group__c__addons__units__speed.html", "group__c__addons__units__speed" ],
    [ "Temperature", "group__c__addons__units__temperature.html", "group__c__addons__units__temperature" ],
    [ "Data", "group__c__addons__units__data.html", "group__c__addons__units__data" ],
    [ "Data Rate", "group__c__addons__units__datarate.html", "group__c__addons__units__datarate" ],
    [ "Angle", "group__c__addons__units__angle.html", "group__c__addons__units__angle" ],
    [ "Uri", "group__c__addons__units__uri.html", "group__c__addons__units__uri" ],
    [ "Color", "group__c__addons__units__color.html", "group__c__addons__units__color" ],
    [ "FlecsUnitsImport", "group__c__addons__units.html#ga1a262c645dc495fbd6754a69f6c8bd60", null ],
    [ "EcsAcceleration", "group__c__addons__units.html#gae2b1f09c1cb4a2befcd9b7ec8361e6ca", null ],
    [ "EcsBel", "group__c__addons__units.html#gaf8013af729a5abe7b7d1ee8fbec7e7fd", null ],
    [ "EcsDeciBel", "group__c__addons__units.html#gaacb26f68f8780b0146b101d9fb6ec413", null ],
    [ "EcsPercentage", "group__c__addons__units.html#ga9bde018551030eb8bbd203f7008ffac1", null ]
];
